LinuxProcessExt

Struct LinuxProcessExt 

pub struct LinuxProcessExt {
    pub apparmor_profile: Option<String>,
    pub capabilities: Option<Capabilities>,
    pub no_new_privileges: Option<bool>,
    pub oom_score_adj: Option<i64>,
    pub selinux_label: Option<String>,
}

Fields

apparmor_profile: Option<String>

specifies the name of the AppArmor profile for the process.

For more information about AppArmor, see AppArmor documentation.

capabilities: Option<Capabilities>

An object containing arrays that specifies the sets of capabilities for the process. Valid values are defined in the capabilities(7) man page, such as CAP_CHOWN. Any value which cannot be mapped to a relevant kernel interface MUST cause an error.

no_new_privileges: Option<bool>

prevents the process from gaining additional privileges. As an example, the no_new_privs article in the kernel documentation has information on how this is achieved using a prctl system call on Linux.

oom_score_adj: Option<i64>

Adjusts the oom-killer score in [pid]/oom_score_adj for the process’s [pid] in a proc pseudo-filesystem. If oomScoreAdj is set, the runtime MUST set oom_score_adj to the given value. If oomScoreAdj is not set, the runtime MUST NOT change the value of oom_score_adj.

This is a per-process setting, where as disableOOMKiller is scoped for a memory cgroup. For more information on how these two settings work together, see the memory cgroup documentation section 10. OOM Contol.

selinux_label: Option<String>

specifies the SELinux label for the process. For more information about SELinux, see SELinux documentation.